uim.codec.format.UIM_3_0_0_pb2 API documentation
Description: Generated protocol buffer code.

# Module `uim.codec.format.UIM_3_0_0_pb2`

Generated protocol buffer code.

Expand source code

    # -*- coding: utf-8 -*-
    # Generated by the protocol buffer compiler.  DO NOT EDIT!
    # source: will-3.proto
    """Generated protocol buffer code."""
    from google.protobuf.internal import enum_type_wrapper
    from google.protobuf import descriptor as _descriptor
    from google.protobuf import message as _message
    from google.protobuf import reflection as _reflection
    from google.protobuf import symbol_database as _symbol_database
    # @@protoc_insertion_point(imports)

    _sym_db = _symbol_database.Default()

    DESCRIPTOR = _descriptor.FileDescriptor(
      name='will-3.proto',
      package='WacomInkFormat3',
      syntax='proto3',
      serialized_options=b'\n\026com.wacom.ink.protobufB\tWill3_0_0H\001P\000\252\002\023Protobuf.WILL_3_0_0',
      create_key=_descriptor._internal_create_key,
      serialized_pb=b'\n\x0cwill-3.proto\x12\x0fWacomInkFormat3\"@\n\tRectangle\x12\t\n\x01x\x18\x01 \x01(\x02\x12\t\n\x01y\x18\x02 \x01(\x02\x12\r\n\x05width\x18\x03 \x01(\x02\x12\x0e\n\x06height\x18\x04 \x01(\x02\"\xd9\x01\n\x07Matrix4\x12\x0b\n\x03m00\x18\x01 \x01(\x02\x12\x0b\n\x03m01\x18\x02 \x01(\x02\x12\x0b\n\x03m02\x18\x03 \x01(\x02\x12\x0b\n\x03m03\x18\x04 \x01(\x02\x12\x0b\n\x03m10\x18\x05 \x01(\x02\x12\x0b\n\x03m11\x18\x06 \x01(\x02\x12\x0b\n\x03m12\x18\x07 \x01(\x02\x12\x0b\n\x03m13\x18\x08 \x01(\x02\x12\x0b\n\x03m20\x18\t \x01(\x02\x12\x0b\n\x03m21\x18\n \x01(\x02\x12\x0b\n\x03m22\x18\x0b \x01(\x02\x12\x0b\n\x03m23\x18\x0c \x01(\x02\x12\x0b\n\x03m30\x18\r \x01(\x02\x12\x0b\n\x03m31\x18\x0e \x01(\x02\x12\x0b\n\x03m32\x18\x0f \x01(\x02\x12\x0b\n\x03m33\x18\x10 \x01(\x02\"q\n\x0e\x42rushPrototype\x12\x0e\n\x06\x63oordX\x18\x01 \x03(\x02\x12\x0e\n\x06\x63oordY\x18\x02 \x03(\x02\x12\x0e\n\x06\x63oordZ\x18\x03 \x03(\x02\x12\x0f\n\x07indices\x18\x04 \x03(\r\x12\x10\n\x08shapeURI\x18\x05 \x01(\t\x12\x0c\n\x04size\x18\x06 \x01(\x02\"3\n\x05Range\x12\x0b\n\x03min\x18\x01 \x01(\x02\x12\x0b\n\x03max\x18\x02 \x01(\x02\x12\x10\n\x08remapURI\x18\x03 \x01(\t\"\x18\n\x07\x46loat32\x12\r\n\x05value\x18\x01 \x01(\x02\"\x17\n\x06Uint32\x12\r\n\x05value\x18\x01 \x01(\r\"\'\n\x08Property\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"D\n\x0eSemanticTriple\x12\x0f\n\x07subject\x18\x01 \x01(\t\x12\x11\n\tpredicate\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"J\n\x0cInputContext\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\renvironmentID\x18\x02 \x01(\t\x12\x17\n\x0fsensorContextID\x18\x03 \x01(\t\"H\n\x0b\x45nvironment\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\nproperties\x18\x02 \x03(\x0b\x32\x19.WacomInkFormat3.Property\"\x82\x01\n\x10InkInputProvider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x33\n\x04type\x18\x02 \x01(\x0e\x32%.WacomInkFormat3.InkInputProviderType\x12-\n\nproperties\x18\x03 \x03(\x0b\x32\x19.WacomInkFormat3.Property\"H\n\x0bInputDevice\x12\n\n\x02id\x18\x01 \x01(\t\x12-\n\nproperties\x18\x02 \x03(\x0b\x32\x19.WacomInkFormat3.Property\"b\n\rSensorContext\x12\n\n\x02id\x18\x01 \x01(\t\x12\x45\n\x15sensorChannelsContext\x18\x02 \x03(\x0b\x32&.WacomInkFormat3.SensorChannelsContext\"\xe5\x01\n\x15SensorChannelsContext\x12\n\n\x02id\x18\x01 \x01(\t\x12\x30\n\x08\x63hannels\x18\x02 \x03(\x0b\x32\x1e.WacomInkFormat3.SensorChannel\x12\x31\n\x10samplingRateHint\x18\x03 \x01(\x0b\x32\x17.WacomInkFormat3.Uint32\x12(\n\x07latency\x18\x04 \x01(\x0b\x32\x17.WacomInkFormat3.Uint32\x12\x1a\n\x12inkInputProviderID\x18\x05 \x01(\t\x12\x15\n\rinputDeviceID\x18\x06 \x01(\t\"\xa0\x01\n\rSensorChannel\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x34\n\x06metric\x18\x03 \x01(\x0e\x32$.WacomInkFormat3.InkSensorMetricType\x12\x12\n\nresolution\x18\x04 \x01(\x01\x12\x0b\n\x03min\x18\x05 \x01(\x02\x12\x0b\n\x03max\x18\x06 \x01(\x02\x12\x11\n\tprecision\x18\x07 \x01(\r\"\xa6\x02\n\x10InputContextData\x12\x34\n\rinputContexts\x18\x01 \x03(\x0b\x32\x1d.WacomInkFormat3.InputContext\x12<\n\x11inkInputProviders\x18\x02 \x03(\x0b\x32!.WacomInkFormat3.InkInputProvider\x12\x32\n\x0cinputDevices\x18\x03 \x03(\x0b\x32\x1c.WacomInkFormat3.InputDevice\x12\x32\n\x0c\x65nvironments\x18\x04 \x03(\x0b\x32\x1c.WacomInkFormat3.Environment\x12\x36\n\x0esensorContexts\x18\x05 \x03(\x0b\x32\x1e.WacomInkFormat3.SensorContext\"6\n\x0b\x43hannelData\x12\x17\n\x0fsensorChannelID\x18\x01 \x01(\t\x12\x0e\n\x06values\x18\x02 \x03(\x11\"\xa1\x01\n\nSensorData\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0einputContextID\x18\x02 \x01(\t\x12(\n\x05state\x18\x03 \x01(\x0e\x32\x19.WacomInkFormat3.InkState\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\x12\x32\n\x0c\x64\x61taChannels\x18\x05 \x03(\x0b\x32\x1c.WacomInkFormat3.ChannelData\"\xa3\x03\n\x06Stroke\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0estartParameter\x18\x02 \x01(\x02\x12\x14\n\x0c\x65ndParameter\x18\x03 \x01(\x02\x12\x0f\n\x07splineX\x18\x04 \x03(\x02\x12\x0f\n\x07splineY\x18\x05 \x03(\x02\x12\x0f\n\x07splineZ\x18\x06 \x03(\x02\x12\x0b\n\x03red\x18\x07 \x03(\x02\x12\r\n\x05green\x18\x08 \x03(\x02\x12\x0c\n\x04\x62lue\x18\t \x03(\x02\x12\r\n\x05\x61lpha\x18\n \x03(\x02\x12\x0c\n\x04size\x18\x0b \x03(\x02\x12\x10\n\x08rotation\x18\x0c \x03(\x02\x12\x0e\n\x06scaleX\x18\r \x03(\x02\x12\x0e\n\x06scaleY\x18\x0e \x03(\x02\x12\x0e\n\x06scaleZ\x18\x0f \x03(\x02\x12\x0f\n\x07offsetX\x18\x10 \x03(\x02\x12\x0f\n\x07offsetY\x18\x11 \x03(\x02\x12\x0f\n\x07offsetZ\x18\x12 \x03(\x02\x12\x18\n\x10sensorDataOffset\x18\x13 \x01(\r\x12\x14\n\x0csensorDataID\x18\x14 \x01(\t\x12\x19\n\x11sensorDataMapping\x18\x15 \x03(\r\x12%\n\x05style\x18\x16 \x01(\x0b\x32\x16.WacomInkFormat3.Style\"`\n\x0bVectorBrush\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x32\n\tprototype\x18\x02 \x03(\x0b\x32\x1f.WacomInkFormat3.BrushPrototype\x12\x0f\n\x07spacing\x18\x03 \x01(\x02\"\xbe\x02\n\x0bRasterBrush\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07spacing\x18\x02 \x01(\x02\x12\x12\n\nscattering\x18\x03 \x01(\x02\x12\x33\n\x0crotationMode\x18\x04 \x01(\x0e\x32\x1d.WacomInkFormat3.RotationMode\x12\x14\n\x0cshapeTexture\x18\x05 \x03(\x0c\x12\x17\n\x0fshapeTextureURI\x18\x06 \x03(\t\x12\x13\n\x0b\x66illTexture\x18\x07 \x01(\x0c\x12\x16\n\x0e\x66illTextureURI\x18\x08 \x01(\t\x12\x11\n\tfillWidth\x18\t \x01(\x02\x12\x12\n\nfillHeight\x18\n \x01(\x02\x12\x15\n\rrandomizeFill\x18\x0b \x01(\x08\x12-\n\tblendMode\x18\x0c \x01(\x0e\x32\x1a.WacomInkFormat3.BlendMode\"\xbd\x01\n\x04Node\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05\x64\x65pth\x18\x02 \x01(\r\x12\r\n\x05index\x18\x03 \x01(\r\x12\'\n\x04type\x18\x04 \x01(\x0e\x32\x19.WacomInkFormat3.NodeType\x12\x34\n\x10groupBoundingBox\x18\x05 \x01(\x0b\x32\x1a.WacomInkFormat3.Rectangle\x12\x16\n\x0e\x63hunkFromIndex\x18\x06 \x01(\r\x12\x14\n\x0c\x63hunkToIndex\x18\x07 \x01(\r\"9\n\x04View\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x04tree\x18\x02 \x03(\x0b\x32\x15.WacomInkFormat3.Node\"\x89\x04\n\x13PathPointProperties\x12&\n\x04size\x18\x01 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12%\n\x03red\x18\x02 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12\'\n\x05green\x18\x03 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12&\n\x04\x62lue\x18\x04 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12\'\n\x05\x61lpha\x18\x05 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12*\n\x08rotation\x18\x06 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12(\n\x06scaleX\x18\x07 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12(\n\x06scaleY\x18\x08 \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12(\n\x06scaleZ\x18\t \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12)\n\x07offsetX\x18\x0b \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12)\n\x07offsetY\x18\x0c \x01(\x0b\x32\x18.WacomInkFormat3.Float32\x12)\n\x07offsetZ\x18\r \x01(\x0b\x32\x18.WacomInkFormat3.Float32\"\x87\x01\n\x05Style\x12\x38\n\nproperties\x18\x01 \x01(\x0b\x32$.WacomInkFormat3.PathPointProperties\x12\x10\n\x08\x62rushURI\x18\x02 \x01(\t\x12\x1b\n\x13particlesRandomSeed\x18\x03 \x01(\r\x12\x15\n\rrenderModeURI\x18\x04 \x01(\t\"y\n\tInputData\x12;\n\x10inputContextData\x18\x01 \x01(\x0b\x32!.WacomInkFormat3.InputContextData\x12/\n\nsensorData\x18\x02 \x03(\x0b\x32\x1b.WacomInkFormat3.SensorData\"3\n\x07InkData\x12(\n\x07strokes\x18\x01 \x03(\x0b\x32\x17.WacomInkFormat3.Stroke\"s\n\x07\x42rushes\x12\x33\n\rvectorBrushes\x18\x01 \x03(\x0b\x32\x1c.WacomInkFormat3.VectorBrush\x12\x33\n\rrasterBrushes\x18\x02 \x03(\x0b\x32\x1c.WacomInkFormat3.RasterBrush\"B\n\x0bTripleStore\x12\x33\n\nstatements\x18\x01 \x03(\x0b\x32\x1f.WacomInkFormat3.SemanticTriple\"\xf0\x02\n\tInkObject\x12-\n\tinputData\x18\x01 \x01(\x0b\x32\x1a.WacomInkFormat3.InputData\x12)\n\x07inkData\x18\x02 \x01(\x0b\x32\x18.WacomInkFormat3.InkData\x12)\n\x07\x62rushes\x18\x03 \x01(\x0b\x32\x18.WacomInkFormat3.Brushes\x12&\n\x07inkTree\x18\x04 \x03(\x0b\x32\x15.WacomInkFormat3.Node\x12$\n\x05views\x18\x05 \x03(\x0b\x32\x15.WacomInkFormat3.View\x12\x34\n\x0eknowledgeGraph\x18\x06 \x01(\x0b\x32\x1c.WacomInkFormat3.TripleStore\x12+\n\ttransform\x18\x07 \x01(\x0b\x32\x18.WacomInkFormat3.Matrix4\x12-\n\nproperties\x18\x08 \x03(\x0b\x32\x19.WacomInkFormat3.Property*G\n\x08InkState\x12\t\n\x05PLANE\x10\x00\x12\x0c\n\x08HOVERING\x10\x01\x12\r\n\tIN_VOLUME\x10\x02\x12\x13\n\x0fVOLUME_HOVERING\x10\x03*q\n\x13InkSensorMetricType\x12\n\n\x06LENGTH\x10\x00\x12\x08\n\x04TIME\x10\x01\x12\t\n\x05\x46ORCE\x10\x02\x12\t\n\x05\x41NGLE\x10\x03\x12\x0e\n\nNORMALIZED\x10\x04\x12\x0b\n\x07LOGICAL\x10\x05\x12\x11\n\rDIMENSIONLESS\x10\x06*E\n\x14InkInputProviderType\x12\x07\n\x03PEN\x10\x00\x12\t\n\x05TOUCH\x10\x01\x12\t\n\x05MOUSE\x10\x02\x12\x0e\n\nCONTROLLER\x10\x03*4\n\x0cRotationMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06RANDOM\x10\x01\x12\x0e\n\nTRAJECTORY\x10\x02*p\n\tBlendMode\x12\x0f\n\x0bSOURCE_OVER\x10\x00\x12\x14\n\x10\x44\x45STINATION_OVER\x10\x01\x12\x13\n\x0f\x44\x45STINATION_OUT\x10\x02\x12\x0b\n\x07LIGHTER\x10\x03\x12\x08\n\x04\x43OPY\x10\x04\x12\x07\n\x03MIN\x10\x05\x12\x07\n\x03MAX\x10\x06*P\n\x08NodeType\x12\x10\n\x0cSTROKE_GROUP\x10\x00\x12\x15\n\x11SENSOR_DATA_GROUP\x10\x01\x12\n\n\x06STROKE\x10\x02\x12\x0f\n\x0bSENSOR_DATA\x10\x03\x42=\n\x16\x63om.wacom.ink.protobufB\tWill3_0_0H\x01P\x00\xaa\x02\x13Protobuf.WILL_3_0_0b\x06proto3'
    )

    _INKSTATE = _descriptor.EnumDescriptor(
      name='InkState',
      full_name='WacomInkFormat3.InkState',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='PLANE', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='HOVERING', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='IN_VOLUME', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='VOLUME_HOVERING', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=4504,
      serialized_end=4575,
    )
    _sym_db.RegisterEnumDescriptor(_INKSTATE)

    InkState = enum_type_wrapper.EnumTypeWrapper(_INKSTATE)
    _INKSENSORMETRICTYPE = _descriptor.EnumDescriptor(
      name='InkSensorMetricType',
      full_name='WacomInkFormat3.InkSensorMetricType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='LENGTH', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='TIME', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='FORCE', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='ANGLE', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='NORMALIZED', index=4, number=4,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='LOGICAL', index=5, number=5,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='DIMENSIONLESS', index=6, number=6,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=4577,
      serialized_end=4690,
    )
    _sym_db.RegisterEnumDescriptor(_INKSENSORMETRICTYPE)

    InkSensorMetricType = enum_type_wrapper.EnumTypeWrapper(_INKSENSORMETRICTYPE)
    _INKINPUTPROVIDERTYPE = _descriptor.EnumDescriptor(
      name='InkInputProviderType',
      full_name='WacomInkFormat3.InkInputProviderType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='PEN', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='TOUCH', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='MOUSE', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='CONTROLLER', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=4692,
      serialized_end=4761,
    )
    _sym_db.RegisterEnumDescriptor(_INKINPUTPROVIDERTYPE)

    InkInputProviderType = enum_type_wrapper.EnumTypeWrapper(_INKINPUTPROVIDERTYPE)
    _ROTATIONMODE = _descriptor.EnumDescriptor(
      name='RotationMode',
      full_name='WacomInkFormat3.RotationMode',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='NONE', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='RANDOM', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='TRAJECTORY', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=4763,
      serialized_end=4815,
    )
    _sym_db.RegisterEnumDescriptor(_ROTATIONMODE)

    RotationMode = enum_type_wrapper.EnumTypeWrapper(_ROTATIONMODE)
    _BLENDMODE = _descriptor.EnumDescriptor(
      name='BlendMode',
      full_name='WacomInkFormat3.BlendMode',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='SOURCE_OVER', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='DESTINATION_OVER', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='DESTINATION_OUT', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='LIGHTER', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='COPY', index=4, number=4,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='MIN', index=5, number=5,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='MAX', index=6, number=6,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=4817,
      serialized_end=4929,
    )
    _sym_db.RegisterEnumDescriptor(_BLENDMODE)

    BlendMode = enum_type_wrapper.EnumTypeWrapper(_BLENDMODE)
    _NODETYPE = _descriptor.EnumDescriptor(
      name='NodeType',
      full_name='WacomInkFormat3.NodeType',
      filename=None,
      file=DESCRIPTOR,
      create_key=_descriptor._internal_create_key,
      values=[
        _descriptor.EnumValueDescriptor(
          name='STROKE_GROUP', index=0, number=0,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='SENSOR_DATA_GROUP', index=1, number=1,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='STROKE', index=2, number=2,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
        _descriptor.EnumValueDescriptor(
          name='SENSOR_DATA', index=3, number=3,
          serialized_options=None,
          type=None,
          create_key=_descriptor._internal_create_key),
      ],
      containing_type=None,
      serialized_options=None,
      serialized_start=4931,
      serialized_end=5011,
    )
    _sym_db.RegisterEnumDescriptor(_NODETYPE)

    NodeType = enum_type_wrapper.EnumTypeWrapper(_NODETYPE)
    PLANE = 0
    HOVERING = 1
    IN_VOLUME = 2
    VOLUME_HOVERING = 3
    LENGTH = 0
    TIME = 1
    FORCE = 2
    ANGLE = 3
    NORMALIZED = 4
    LOGICAL = 5
    DIMENSIONLESS = 6
    PEN = 0
    TOUCH = 1
    MOUSE = 2
    CONTROLLER = 3
    NONE = 0
    RANDOM = 1
    TRAJECTORY = 2
    SOURCE_OVER = 0
    DESTINATION_OVER = 1
    DESTINATION_OUT = 2
    LIGHTER = 3
    COPY = 4
    MIN = 5
    MAX = 6
    STROKE_GROUP = 0
    SENSOR_DATA_GROUP = 1
    STROKE = 2
    SENSOR_DATA = 3

    _RECTANGLE = _descriptor.Descriptor(
      name='Rectangle',
      full_name='WacomInkFormat3.Rectangle',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='x', full_name='WacomInkFormat3.Rectangle.x', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='y', full_name='WacomInkFormat3.Rectangle.y', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='width', full_name='WacomInkFormat3.Rectangle.width', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='height', full_name='WacomInkFormat3.Rectangle.height', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=33,
      serialized_end=97,
    )

    _MATRIX4 = _descriptor.Descriptor(
      name='Matrix4',
      full_name='WacomInkFormat3.Matrix4',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='m00', full_name='WacomInkFormat3.Matrix4.m00', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m01', full_name='WacomInkFormat3.Matrix4.m01', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m02', full_name='WacomInkFormat3.Matrix4.m02', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m03', full_name='WacomInkFormat3.Matrix4.m03', index=3,
          number=4, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m10', full_name='WacomInkFormat3.Matrix4.m10', index=4,
          number=5, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m11', full_name='WacomInkFormat3.Matrix4.m11', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m12', full_name='WacomInkFormat3.Matrix4.m12', index=6,
          number=7, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m13', full_name='WacomInkFormat3.Matrix4.m13', index=7,
          number=8, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m20', full_name='WacomInkFormat3.Matrix4.m20', index=8,
          number=9, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m21', full_name='WacomInkFormat3.Matrix4.m21', index=9,
          number=10, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m22', full_name='WacomInkFormat3.Matrix4.m22', index=10,
          number=11, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m23', full_name='WacomInkFormat3.Matrix4.m23', index=11,
          number=12, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m30', full_name='WacomInkFormat3.Matrix4.m30', index=12,
          number=13, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m31', full_name='WacomInkFormat3.Matrix4.m31', index=13,
          number=14, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m32', full_name='WacomInkFormat3.Matrix4.m32', index=14,
          number=15, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='m33', full_name='WacomInkFormat3.Matrix4.m33', index=15,
          number=16, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=100,
      serialized_end=317,
    )

    _BRUSHPROTOTYPE = _descriptor.Descriptor(
      name='BrushPrototype',
      full_name='WacomInkFormat3.BrushPrototype',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='coordX', full_name='WacomInkFormat3.BrushPrototype.coordX', index=0,
          number=1, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='coordY', full_name='WacomInkFormat3.BrushPrototype.coordY', index=1,
          number=2, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='coordZ', full_name='WacomInkFormat3.BrushPrototype.coordZ', index=2,
          number=3, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='indices', full_name='WacomInkFormat3.BrushPrototype.indices', index=3,
          number=4, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='shapeURI', full_name='WacomInkFormat3.BrushPrototype.shapeURI', index=4,
          number=5, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='size', full_name='WacomInkFormat3.BrushPrototype.size', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=319,
      serialized_end=432,
    )

    _RANGE = _descriptor.Descriptor(
      name='Range',
      full_name='WacomInkFormat3.Range',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='min', full_name='WacomInkFormat3.Range.min', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='max', full_name='WacomInkFormat3.Range.max', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='remapURI', full_name='WacomInkFormat3.Range.remapURI', index=2,
          number=3, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=434,
      serialized_end=485,
    )

    _FLOAT32 = _descriptor.Descriptor(
      name='Float32',
      full_name='WacomInkFormat3.Float32',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='value', full_name='WacomInkFormat3.Float32.value', index=0,
          number=1, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=487,
      serialized_end=511,
    )

    _UINT32 = _descriptor.Descriptor(
      name='Uint32',
      full_name='WacomInkFormat3.Uint32',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='value', full_name='WacomInkFormat3.Uint32.value', index=0,
          number=1, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=513,
      serialized_end=536,
    )

    _PROPERTY = _descriptor.Descriptor(
      name='Property',
      full_name='WacomInkFormat3.Property',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='WacomInkFormat3.Property.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='value', full_name='WacomInkFormat3.Property.value', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=538,
      serialized_end=577,
    )

    _SEMANTICTRIPLE = _descriptor.Descriptor(
      name='SemanticTriple',
      full_name='WacomInkFormat3.SemanticTriple',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='subject', full_name='WacomInkFormat3.SemanticTriple.subject', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='predicate', full_name='WacomInkFormat3.SemanticTriple.predicate', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='object', full_name='WacomInkFormat3.SemanticTriple.object', index=2,
          number=3, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=579,
      serialized_end=647,
    )

    _INPUTCONTEXT = _descriptor.Descriptor(
      name='InputContext',
      full_name='WacomInkFormat3.InputContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.InputContext.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='environmentID', full_name='WacomInkFormat3.InputContext.environmentID', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorContextID', full_name='WacomInkFormat3.InputContext.sensorContextID', index=2,
          number=3, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=649,
      serialized_end=723,
    )

    _ENVIRONMENT = _descriptor.Descriptor(
      name='Environment',
      full_name='WacomInkFormat3.Environment',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.Environment.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='WacomInkFormat3.Environment.properties', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=725,
      serialized_end=797,
    )

    _INKINPUTPROVIDER = _descriptor.Descriptor(
      name='InkInputProvider',
      full_name='WacomInkFormat3.InkInputProvider',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.InkInputProvider.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='type', full_name='WacomInkFormat3.InkInputProvider.type', index=1,
          number=2, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='WacomInkFormat3.InkInputProvider.properties', index=2,
          number=3, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=800,
      serialized_end=930,
    )

    _INPUTDEVICE = _descriptor.Descriptor(
      name='InputDevice',
      full_name='WacomInkFormat3.InputDevice',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.InputDevice.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='WacomInkFormat3.InputDevice.properties', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=932,
      serialized_end=1004,
    )

    _SENSORCONTEXT = _descriptor.Descriptor(
      name='SensorContext',
      full_name='WacomInkFormat3.SensorContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.SensorContext.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorChannelsContext', full_name='WacomInkFormat3.SensorContext.sensorChannelsContext', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1006,
      serialized_end=1104,
    )

    _SENSORCHANNELSCONTEXT = _descriptor.Descriptor(
      name='SensorChannelsContext',
      full_name='WacomInkFormat3.SensorChannelsContext',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.SensorChannelsContext.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='channels', full_name='WacomInkFormat3.SensorChannelsContext.channels', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='samplingRateHint', full_name='WacomInkFormat3.SensorChannelsContext.samplingRateHint', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='latency', full_name='WacomInkFormat3.SensorChannelsContext.latency', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkInputProviderID', full_name='WacomInkFormat3.SensorChannelsContext.inkInputProviderID', index=4,
          number=5, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inputDeviceID', full_name='WacomInkFormat3.SensorChannelsContext.inputDeviceID', index=5,
          number=6, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1107,
      serialized_end=1336,
    )

    _SENSORCHANNEL = _descriptor.Descriptor(
      name='SensorChannel',
      full_name='WacomInkFormat3.SensorChannel',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.SensorChannel.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='type', full_name='WacomInkFormat3.SensorChannel.type', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='metric', full_name='WacomInkFormat3.SensorChannel.metric', index=2,
          number=3, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='resolution', full_name='WacomInkFormat3.SensorChannel.resolution', index=3,
          number=4, type=1, cpp_type=5, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='min', full_name='WacomInkFormat3.SensorChannel.min', index=4,
          number=5, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='max', full_name='WacomInkFormat3.SensorChannel.max', index=5,
          number=6, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='precision', full_name='WacomInkFormat3.SensorChannel.precision', index=6,
          number=7, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1339,
      serialized_end=1499,
    )

    _INPUTCONTEXTDATA = _descriptor.Descriptor(
      name='InputContextData',
      full_name='WacomInkFormat3.InputContextData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='inputContexts', full_name='WacomInkFormat3.InputContextData.inputContexts', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkInputProviders', full_name='WacomInkFormat3.InputContextData.inkInputProviders', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inputDevices', full_name='WacomInkFormat3.InputContextData.inputDevices', index=2,
          number=3, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='environments', full_name='WacomInkFormat3.InputContextData.environments', index=3,
          number=4, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorContexts', full_name='WacomInkFormat3.InputContextData.sensorContexts', index=4,
          number=5, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1502,
      serialized_end=1796,
    )

    _CHANNELDATA = _descriptor.Descriptor(
      name='ChannelData',
      full_name='WacomInkFormat3.ChannelData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='sensorChannelID', full_name='WacomInkFormat3.ChannelData.sensorChannelID', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='values', full_name='WacomInkFormat3.ChannelData.values', index=1,
          number=2, type=17, cpp_type=1, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1798,
      serialized_end=1852,
    )

    _SENSORDATA = _descriptor.Descriptor(
      name='SensorData',
      full_name='WacomInkFormat3.SensorData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.SensorData.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inputContextID', full_name='WacomInkFormat3.SensorData.inputContextID', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='state', full_name='WacomInkFormat3.SensorData.state', index=2,
          number=3, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='timestamp', full_name='WacomInkFormat3.SensorData.timestamp', index=3,
          number=4, type=4, cpp_type=4, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='dataChannels', full_name='WacomInkFormat3.SensorData.dataChannels', index=4,
          number=5, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=1855,
      serialized_end=2016,
    )

    _STROKE = _descriptor.Descriptor(
      name='Stroke',
      full_name='WacomInkFormat3.Stroke',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.Stroke.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='startParameter', full_name='WacomInkFormat3.Stroke.startParameter', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='endParameter', full_name='WacomInkFormat3.Stroke.endParameter', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineX', full_name='WacomInkFormat3.Stroke.splineX', index=3,
          number=4, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineY', full_name='WacomInkFormat3.Stroke.splineY', index=4,
          number=5, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='splineZ', full_name='WacomInkFormat3.Stroke.splineZ', index=5,
          number=6, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='red', full_name='WacomInkFormat3.Stroke.red', index=6,
          number=7, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='green', full_name='WacomInkFormat3.Stroke.green', index=7,
          number=8, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blue', full_name='WacomInkFormat3.Stroke.blue', index=8,
          number=9, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='alpha', full_name='WacomInkFormat3.Stroke.alpha', index=9,
          number=10, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='size', full_name='WacomInkFormat3.Stroke.size', index=10,
          number=11, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotation', full_name='WacomInkFormat3.Stroke.rotation', index=11,
          number=12, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleX', full_name='WacomInkFormat3.Stroke.scaleX', index=12,
          number=13, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleY', full_name='WacomInkFormat3.Stroke.scaleY', index=13,
          number=14, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleZ', full_name='WacomInkFormat3.Stroke.scaleZ', index=14,
          number=15, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetX', full_name='WacomInkFormat3.Stroke.offsetX', index=15,
          number=16, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetY', full_name='WacomInkFormat3.Stroke.offsetY', index=16,
          number=17, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetZ', full_name='WacomInkFormat3.Stroke.offsetZ', index=17,
          number=18, type=2, cpp_type=6, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorDataOffset', full_name='WacomInkFormat3.Stroke.sensorDataOffset', index=18,
          number=19, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorDataID', full_name='WacomInkFormat3.Stroke.sensorDataID', index=19,
          number=20, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorDataMapping', full_name='WacomInkFormat3.Stroke.sensorDataMapping', index=20,
          number=21, type=13, cpp_type=3, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='style', full_name='WacomInkFormat3.Stroke.style', index=21,
          number=22, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2019,
      serialized_end=2438,
    )

    _VECTORBRUSH = _descriptor.Descriptor(
      name='VectorBrush',
      full_name='WacomInkFormat3.VectorBrush',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='WacomInkFormat3.VectorBrush.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='prototype', full_name='WacomInkFormat3.VectorBrush.prototype', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='spacing', full_name='WacomInkFormat3.VectorBrush.spacing', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2440,
      serialized_end=2536,
    )

    _RASTERBRUSH = _descriptor.Descriptor(
      name='RasterBrush',
      full_name='WacomInkFormat3.RasterBrush',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='WacomInkFormat3.RasterBrush.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='spacing', full_name='WacomInkFormat3.RasterBrush.spacing', index=1,
          number=2, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scattering', full_name='WacomInkFormat3.RasterBrush.scattering', index=2,
          number=3, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotationMode', full_name='WacomInkFormat3.RasterBrush.rotationMode', index=3,
          number=4, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='shapeTexture', full_name='WacomInkFormat3.RasterBrush.shapeTexture', index=4,
          number=5, type=12, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='shapeTextureURI', full_name='WacomInkFormat3.RasterBrush.shapeTextureURI', index=5,
          number=6, type=9, cpp_type=9, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillTexture', full_name='WacomInkFormat3.RasterBrush.fillTexture', index=6,
          number=7, type=12, cpp_type=9, label=1,
          has_default_value=False, default_value=b"",
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillTextureURI', full_name='WacomInkFormat3.RasterBrush.fillTextureURI', index=7,
          number=8, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillWidth', full_name='WacomInkFormat3.RasterBrush.fillWidth', index=8,
          number=9, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='fillHeight', full_name='WacomInkFormat3.RasterBrush.fillHeight', index=9,
          number=10, type=2, cpp_type=6, label=1,
          has_default_value=False, default_value=float(0),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='randomizeFill', full_name='WacomInkFormat3.RasterBrush.randomizeFill', index=10,
          number=11, type=8, cpp_type=7, label=1,
          has_default_value=False, default_value=False,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blendMode', full_name='WacomInkFormat3.RasterBrush.blendMode', index=11,
          number=12, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2539,
      serialized_end=2857,
    )

    _NODE = _descriptor.Descriptor(
      name='Node',
      full_name='WacomInkFormat3.Node',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='id', full_name='WacomInkFormat3.Node.id', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='depth', full_name='WacomInkFormat3.Node.depth', index=1,
          number=2, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='index', full_name='WacomInkFormat3.Node.index', index=2,
          number=3, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='type', full_name='WacomInkFormat3.Node.type', index=3,
          number=4, type=14, cpp_type=8, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='groupBoundingBox', full_name='WacomInkFormat3.Node.groupBoundingBox', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='chunkFromIndex', full_name='WacomInkFormat3.Node.chunkFromIndex', index=5,
          number=6, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='chunkToIndex', full_name='WacomInkFormat3.Node.chunkToIndex', index=6,
          number=7, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=2860,
      serialized_end=3049,
    )

    _VIEW = _descriptor.Descriptor(
      name='View',
      full_name='WacomInkFormat3.View',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='name', full_name='WacomInkFormat3.View.name', index=0,
          number=1, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='tree', full_name='WacomInkFormat3.View.tree', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3051,
      serialized_end=3108,
    )

    _PATHPOINTPROPERTIES = _descriptor.Descriptor(
      name='PathPointProperties',
      full_name='WacomInkFormat3.PathPointProperties',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='size', full_name='WacomInkFormat3.PathPointProperties.size', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='red', full_name='WacomInkFormat3.PathPointProperties.red', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='green', full_name='WacomInkFormat3.PathPointProperties.green', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='blue', full_name='WacomInkFormat3.PathPointProperties.blue', index=3,
          number=4, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='alpha', full_name='WacomInkFormat3.PathPointProperties.alpha', index=4,
          number=5, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rotation', full_name='WacomInkFormat3.PathPointProperties.rotation', index=5,
          number=6, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleX', full_name='WacomInkFormat3.PathPointProperties.scaleX', index=6,
          number=7, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleY', full_name='WacomInkFormat3.PathPointProperties.scaleY', index=7,
          number=8, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='scaleZ', full_name='WacomInkFormat3.PathPointProperties.scaleZ', index=8,
          number=9, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetX', full_name='WacomInkFormat3.PathPointProperties.offsetX', index=9,
          number=11, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetY', full_name='WacomInkFormat3.PathPointProperties.offsetY', index=10,
          number=12, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='offsetZ', full_name='WacomInkFormat3.PathPointProperties.offsetZ', index=11,
          number=13, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3111,
      serialized_end=3632,
    )

    _STYLE = _descriptor.Descriptor(
      name='Style',
      full_name='WacomInkFormat3.Style',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='properties', full_name='WacomInkFormat3.Style.properties', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='brushURI', full_name='WacomInkFormat3.Style.brushURI', index=1,
          number=2, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='particlesRandomSeed', full_name='WacomInkFormat3.Style.particlesRandomSeed', index=2,
          number=3, type=13, cpp_type=3, label=1,
          has_default_value=False, default_value=0,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='renderModeURI', full_name='WacomInkFormat3.Style.renderModeURI', index=3,
          number=4, type=9, cpp_type=9, label=1,
          has_default_value=False, default_value=b"".decode('utf-8'),
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3635,
      serialized_end=3770,
    )

    _INPUTDATA = _descriptor.Descriptor(
      name='InputData',
      full_name='WacomInkFormat3.InputData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='inputContextData', full_name='WacomInkFormat3.InputData.inputContextData', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='sensorData', full_name='WacomInkFormat3.InputData.sensorData', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3772,
      serialized_end=3893,
    )

    _INKDATA = _descriptor.Descriptor(
      name='InkData',
      full_name='WacomInkFormat3.InkData',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='strokes', full_name='WacomInkFormat3.InkData.strokes', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3895,
      serialized_end=3946,
    )

    _BRUSHES = _descriptor.Descriptor(
      name='Brushes',
      full_name='WacomInkFormat3.Brushes',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='vectorBrushes', full_name='WacomInkFormat3.Brushes.vectorBrushes', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='rasterBrushes', full_name='WacomInkFormat3.Brushes.rasterBrushes', index=1,
          number=2, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=3948,
      serialized_end=4063,
    )

    _TRIPLESTORE = _descriptor.Descriptor(
      name='TripleStore',
      full_name='WacomInkFormat3.TripleStore',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='statements', full_name='WacomInkFormat3.TripleStore.statements', index=0,
          number=1, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4065,
      serialized_end=4131,
    )

    _INKOBJECT = _descriptor.Descriptor(
      name='InkObject',
      full_name='WacomInkFormat3.InkObject',
      filename=None,
      file=DESCRIPTOR,
      containing_type=None,
      create_key=_descriptor._internal_create_key,
      fields=[
        _descriptor.FieldDescriptor(
          name='inputData', full_name='WacomInkFormat3.InkObject.inputData', index=0,
          number=1, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkData', full_name='WacomInkFormat3.InkObject.inkData', index=1,
          number=2, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='brushes', full_name='WacomInkFormat3.InkObject.brushes', index=2,
          number=3, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='inkTree', full_name='WacomInkFormat3.InkObject.inkTree', index=3,
          number=4, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='views', full_name='WacomInkFormat3.InkObject.views', index=4,
          number=5, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='knowledgeGraph', full_name='WacomInkFormat3.InkObject.knowledgeGraph', index=5,
          number=6, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='transform', full_name='WacomInkFormat3.InkObject.transform', index=6,
          number=7, type=11, cpp_type=10, label=1,
          has_default_value=False, default_value=None,
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
        _descriptor.FieldDescriptor(
          name='properties', full_name='WacomInkFormat3.InkObject.properties', index=7,
          number=8, type=11, cpp_type=10, label=3,
          has_default_value=False, default_value=[],
          message_type=None, enum_type=None, containing_type=None,
          is_extension=False, extension_scope=None,
          serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
      ],
      extensions=[
      ],
      nested_types=[],
      enum_types=[
      ],
      serialized_options=None,
      is_extendable=False,
      syntax='proto3',
      extension_ranges=[],
      oneofs=[
      ],
      serialized_start=4134,
      serialized_end=4502,
    )

    _ENVIRONMENT.fields_by_name['properties'].message_type = _PROPERTY
    _INKINPUTPROVIDER.fields_by_name['type'].enum_type = _INKINPUTPROVIDERTYPE
    _INKINPUTPROVIDER.fields_by_name['properties'].message_type = _PROPERTY
    _INPUTDEVICE.fields_by_name['properties'].message_type = _PROPERTY
    _SENSORCONTEXT.fields_by_name['sensorChannelsContext'].message_type = _SENSORCHANNELSCONTEXT
    _SENSORCHANNELSCONTEXT.fields_by_name['channels'].message_type = _SENSORCHANNEL
    _SENSORCHANNELSCONTEXT.fields_by_name['samplingRateHint'].message_type = _UINT32
    _SENSORCHANNELSCONTEXT.fields_by_name['latency'].message_type = _UINT32
    _SENSORCHANNEL.fields_by_name['metric'].enum_type = _INKSENSORMETRICTYPE
    _INPUTCONTEXTDATA.fields_by_name['inputContexts'].message_type = _INPUTCONTEXT
    _INPUTCONTEXTDATA.fields_by_name['inkInputProviders'].message_type = _INKINPUTPROVIDER
    _INPUTCONTEXTDATA.fields_by_name['inputDevices'].message_type = _INPUTDEVICE
    _INPUTCONTEXTDATA.fields_by_name['environments'].message_type = _ENVIRONMENT
    _INPUTCONTEXTDATA.fields_by_name['sensorContexts'].message_type = _SENSORCONTEXT
    _SENSORDATA.fields_by_name['state'].enum_type = _INKSTATE
    _SENSORDATA.fields_by_name['dataChannels'].message_type = _CHANNELDATA
    _STROKE.fields_by_name['style'].message_type = _STYLE
    _VECTORBRUSH.fields_by_name['prototype'].message_type = _BRUSHPROTOTYPE
    _RASTERBRUSH.fields_by_name['rotationMode'].enum_type = _ROTATIONMODE
    _RASTERBRUSH.fields_by_name['blendMode'].enum_type = _BLENDMODE
    _NODE.fields_by_name['type'].enum_type = _NODETYPE
    _NODE.fields_by_name['groupBoundingBox'].message_type = _RECTANGLE
    _VIEW.fields_by_name['tree'].message_type = _NODE
    _PATHPOINTPROPERTIES.fields_by_name['size'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['red'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['green'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['blue'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['alpha'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['rotation'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['scaleX'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['scaleY'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['scaleZ'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['offsetX'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['offsetY'].message_type = _FLOAT32
    _PATHPOINTPROPERTIES.fields_by_name['offsetZ'].message_type = _FLOAT32
    _STYLE.fields_by_name['properties'].message_type = _PATHPOINTPROPERTIES
    _INPUTDATA.fields_by_name['inputContextData'].message_type = _INPUTCONTEXTDATA
    _INPUTDATA.fields_by_name['sensorData'].message_type = _SENSORDATA
    _INKDATA.fields_by_name['strokes'].message_type = _STROKE
    _BRUSHES.fields_by_name['vectorBrushes'].message_type = _VECTORBRUSH
    _BRUSHES.fields_by_name['rasterBrushes'].message_type = _RASTERBRUSH
    _TRIPLESTORE.fields_by_name['statements'].message_type = _SEMANTICTRIPLE
    _INKOBJECT.fields_by_name['inputData'].message_type = _INPUTDATA
    _INKOBJECT.fields_by_name['inkData'].message_type = _INKDATA
    _INKOBJECT.fields_by_name['brushes'].message_type = _BRUSHES
    _INKOBJECT.fields_by_name['inkTree'].message_type = _NODE
    _INKOBJECT.fields_by_name['views'].message_type = _VIEW
    _INKOBJECT.fields_by_name['knowledgeGraph'].message_type = _TRIPLESTORE
    _INKOBJECT.fields_by_name['transform'].message_type = _MATRIX4
    _INKOBJECT.fields_by_name['properties'].message_type = _PROPERTY
    DESCRIPTOR.message_types_by_name['Rectangle'] = _RECTANGLE
    DESCRIPTOR.message_types_by_name['Matrix4'] = _MATRIX4
    DESCRIPTOR.message_types_by_name['BrushPrototype'] = _BRUSHPROTOTYPE
    DESCRIPTOR.message_types_by_name['Range'] = _RANGE
    DESCRIPTOR.message_types_by_name['Float32'] = _FLOAT32
    DESCRIPTOR.message_types_by_name['Uint32'] = _UINT32
    DESCRIPTOR.message_types_by_name['Property'] = _PROPERTY
    DESCRIPTOR.message_types_by_name['SemanticTriple'] = _SEMANTICTRIPLE
    DESCRIPTOR.message_types_by_name['InputContext'] = _INPUTCONTEXT
    DESCRIPTOR.message_types_by_name['Environment'] = _ENVIRONMENT
    DESCRIPTOR.message_types_by_name['InkInputProvider'] = _INKINPUTPROVIDER
    DESCRIPTOR.message_types_by_name['InputDevice'] = _INPUTDEVICE
    DESCRIPTOR.message_types_by_name['SensorContext'] = _SENSORCONTEXT
    DESCRIPTOR.message_types_by_name['SensorChannelsContext'] = _SENSORCHANNELSCONTEXT
    DESCRIPTOR.message_types_by_name['SensorChannel'] = _SENSORCHANNEL
    DESCRIPTOR.message_types_by_name['InputContextData'] = _INPUTCONTEXTDATA
    DESCRIPTOR.message_types_by_name['ChannelData'] = _CHANNELDATA
    DESCRIPTOR.message_types_by_name['SensorData'] = _SENSORDATA
    DESCRIPTOR.message_types_by_name['Stroke'] = _STROKE
    DESCRIPTOR.message_types_by_name['VectorBrush'] = _VECTORBRUSH
    DESCRIPTOR.message_types_by_name['RasterBrush'] = _RASTERBRUSH
    DESCRIPTOR.message_types_by_name['Node'] = _NODE
    DESCRIPTOR.message_types_by_name['View'] = _VIEW
    DESCRIPTOR.message_types_by_name['PathPointProperties'] = _PATHPOINTPROPERTIES
    DESCRIPTOR.message_types_by_name['Style'] = _STYLE
    DESCRIPTOR.message_types_by_name['InputData'] = _INPUTDATA
    DESCRIPTOR.message_types_by_name['InkData'] = _INKDATA
    DESCRIPTOR.message_types_by_name['Brushes'] = _BRUSHES
    DESCRIPTOR.message_types_by_name['TripleStore'] = _TRIPLESTORE
    DESCRIPTOR.message_types_by_name['InkObject'] = _INKOBJECT
    DESCRIPTOR.enum_types_by_name['InkState'] = _INKSTATE
    DESCRIPTOR.enum_types_by_name['InkSensorMetricType'] = _INKSENSORMETRICTYPE
    DESCRIPTOR.enum_types_by_name['InkInputProviderType'] = _INKINPUTPROVIDERTYPE
    DESCRIPTOR.enum_types_by_name['RotationMode'] = _ROTATIONMODE
    DESCRIPTOR.enum_types_by_name['BlendMode'] = _BLENDMODE
    DESCRIPTOR.enum_types_by_name['NodeType'] = _NODETYPE
    _sym_db.RegisterFileDescriptor(DESCRIPTOR)

    Rectangle = _reflection.GeneratedProtocolMessageType('Rectangle', (_message.Message,), {
      'DESCRIPTOR' : _RECTANGLE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Rectangle)
      })
    _sym_db.RegisterMessage(Rectangle)

    Matrix4 = _reflection.GeneratedProtocolMessageType('Matrix4', (_message.Message,), {
      'DESCRIPTOR' : _MATRIX4,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Matrix4)
      })
    _sym_db.RegisterMessage(Matrix4)

    BrushPrototype = _reflection.GeneratedProtocolMessageType('BrushPrototype', (_message.Message,), {
      'DESCRIPTOR' : _BRUSHPROTOTYPE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.BrushPrototype)
      })
    _sym_db.RegisterMessage(BrushPrototype)

    Range = _reflection.GeneratedProtocolMessageType('Range', (_message.Message,), {
      'DESCRIPTOR' : _RANGE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Range)
      })
    _sym_db.RegisterMessage(Range)

    Float32 = _reflection.GeneratedProtocolMessageType('Float32', (_message.Message,), {
      'DESCRIPTOR' : _FLOAT32,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Float32)
      })
    _sym_db.RegisterMessage(Float32)

    Uint32 = _reflection.GeneratedProtocolMessageType('Uint32', (_message.Message,), {
      'DESCRIPTOR' : _UINT32,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Uint32)
      })
    _sym_db.RegisterMessage(Uint32)

    Property = _reflection.GeneratedProtocolMessageType('Property', (_message.Message,), {
      'DESCRIPTOR' : _PROPERTY,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Property)
      })
    _sym_db.RegisterMessage(Property)

    SemanticTriple = _reflection.GeneratedProtocolMessageType('SemanticTriple', (_message.Message,), {
      'DESCRIPTOR' : _SEMANTICTRIPLE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.SemanticTriple)
      })
    _sym_db.RegisterMessage(SemanticTriple)

    InputContext = _reflection.GeneratedProtocolMessageType('InputContext', (_message.Message,), {
      'DESCRIPTOR' : _INPUTCONTEXT,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InputContext)
      })
    _sym_db.RegisterMessage(InputContext)

    Environment = _reflection.GeneratedProtocolMessageType('Environment', (_message.Message,), {
      'DESCRIPTOR' : _ENVIRONMENT,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Environment)
      })
    _sym_db.RegisterMessage(Environment)

    InkInputProvider = _reflection.GeneratedProtocolMessageType('InkInputProvider', (_message.Message,), {
      'DESCRIPTOR' : _INKINPUTPROVIDER,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InkInputProvider)
      })
    _sym_db.RegisterMessage(InkInputProvider)

    InputDevice = _reflection.GeneratedProtocolMessageType('InputDevice', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDEVICE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InputDevice)
      })
    _sym_db.RegisterMessage(InputDevice)

    SensorContext = _reflection.GeneratedProtocolMessageType('SensorContext', (_message.Message,), {
      'DESCRIPTOR' : _SENSORCONTEXT,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.SensorContext)
      })
    _sym_db.RegisterMessage(SensorContext)

    SensorChannelsContext = _reflection.GeneratedProtocolMessageType('SensorChannelsContext', (_message.Message,), {
      'DESCRIPTOR' : _SENSORCHANNELSCONTEXT,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.SensorChannelsContext)
      })
    _sym_db.RegisterMessage(SensorChannelsContext)

    SensorChannel = _reflection.GeneratedProtocolMessageType('SensorChannel', (_message.Message,), {
      'DESCRIPTOR' : _SENSORCHANNEL,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.SensorChannel)
      })
    _sym_db.RegisterMessage(SensorChannel)

    InputContextData = _reflection.GeneratedProtocolMessageType('InputContextData', (_message.Message,), {
      'DESCRIPTOR' : _INPUTCONTEXTDATA,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InputContextData)
      })
    _sym_db.RegisterMessage(InputContextData)

    ChannelData = _reflection.GeneratedProtocolMessageType('ChannelData', (_message.Message,), {
      'DESCRIPTOR' : _CHANNELDATA,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.ChannelData)
      })
    _sym_db.RegisterMessage(ChannelData)

    SensorData = _reflection.GeneratedProtocolMessageType('SensorData', (_message.Message,), {
      'DESCRIPTOR' : _SENSORDATA,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.SensorData)
      })
    _sym_db.RegisterMessage(SensorData)

    Stroke = _reflection.GeneratedProtocolMessageType('Stroke', (_message.Message,), {
      'DESCRIPTOR' : _STROKE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Stroke)
      })
    _sym_db.RegisterMessage(Stroke)

    VectorBrush = _reflection.GeneratedProtocolMessageType('VectorBrush', (_message.Message,), {
      'DESCRIPTOR' : _VECTORBRUSH,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.VectorBrush)
      })
    _sym_db.RegisterMessage(VectorBrush)

    RasterBrush = _reflection.GeneratedProtocolMessageType('RasterBrush', (_message.Message,), {
      'DESCRIPTOR' : _RASTERBRUSH,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.RasterBrush)
      })
    _sym_db.RegisterMessage(RasterBrush)

    Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), {
      'DESCRIPTOR' : _NODE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Node)
      })
    _sym_db.RegisterMessage(Node)

    View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
      'DESCRIPTOR' : _VIEW,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.View)
      })
    _sym_db.RegisterMessage(View)

    PathPointProperties = _reflection.GeneratedProtocolMessageType('PathPointProperties', (_message.Message,), {
      'DESCRIPTOR' : _PATHPOINTPROPERTIES,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.PathPointProperties)
      })
    _sym_db.RegisterMessage(PathPointProperties)

    Style = _reflection.GeneratedProtocolMessageType('Style', (_message.Message,), {
      'DESCRIPTOR' : _STYLE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Style)
      })
    _sym_db.RegisterMessage(Style)

    InputData = _reflection.GeneratedProtocolMessageType('InputData', (_message.Message,), {
      'DESCRIPTOR' : _INPUTDATA,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InputData)
      })
    _sym_db.RegisterMessage(InputData)

    InkData = _reflection.GeneratedProtocolMessageType('InkData', (_message.Message,), {
      'DESCRIPTOR' : _INKDATA,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InkData)
      })
    _sym_db.RegisterMessage(InkData)

    Brushes = _reflection.GeneratedProtocolMessageType('Brushes', (_message.Message,), {
      'DESCRIPTOR' : _BRUSHES,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.Brushes)
      })
    _sym_db.RegisterMessage(Brushes)

    TripleStore = _reflection.GeneratedProtocolMessageType('TripleStore', (_message.Message,), {
      'DESCRIPTOR' : _TRIPLESTORE,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.TripleStore)
      })
    _sym_db.RegisterMessage(TripleStore)

    InkObject = _reflection.GeneratedProtocolMessageType('InkObject', (_message.Message,), {
      'DESCRIPTOR' : _INKOBJECT,
      '__module__' : 'will_3_pb2'
      # @@protoc_insertion_point(class_scope:WacomInkFormat3.InkObject)
      })
    _sym_db.RegisterMessage(InkObject)

    DESCRIPTOR._options = None
    # @@protoc_insertion_point(module_scope)

## Classes

`class BrushPrototype (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var coordX`

    Field WacomInkFormat3.BrushPrototype.coordX

  `var coordY`

    Field WacomInkFormat3.BrushPrototype.coordY

  `var coordZ`

    Field WacomInkFormat3.BrushPrototype.coordZ

  `var indices`

    Field WacomInkFormat3.BrushPrototype.indices

  `var shapeURI`

    Field WacomInkFormat3.BrushPrototype.shapeURI

  `var size`

    Field WacomInkFormat3.BrushPrototype.size

`class Brushes (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var rasterBrushes`

    Field WacomInkFormat3.Brushes.rasterBrushes

  `var vectorBrushes`

    Field WacomInkFormat3.Brushes.vectorBrushes

`class ChannelData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var sensorChannelID`

    Field WacomInkFormat3.ChannelData.sensorChannelID

  `var values`

    Field WacomInkFormat3.ChannelData.values

`class Environment (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field WacomInkFormat3.Environment.id

  `var properties`

    Field WacomInkFormat3.Environment.properties

`class Float32 (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var value`

    Field WacomInkFormat3.Float32.value

`class InkData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var strokes`

    Field WacomInkFormat3.InkData.strokes

`class InkInputProvider (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field WacomInkFormat3.InkInputProvider.id

  `var properties`

    Field WacomInkFormat3.InkInputProvider.properties

  `var type`

    Field WacomInkFormat3.InkInputProvider.type

`class InkObject (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var brushes`

    Field WacomInkFormat3.InkObject.brushes

  `var inkData`

    Field WacomInkFormat3.InkObject.inkData

  `var inkTree`

    Field WacomInkFormat3.InkObject.inkTree

  `var inputData`

    Field WacomInkFormat3.InkObject.inputData

  `var knowledgeGraph`

    Field WacomInkFormat3.InkObject.knowledgeGraph

  `var properties`

    Field WacomInkFormat3.InkObject.properties

  `var transform`

    Field WacomInkFormat3.InkObject.transform

  `var views`

    Field WacomInkFormat3.InkObject.views

`class InputContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var environmentID`

    Field WacomInkFormat3.InputContext.environmentID

  `var id`

    Field WacomInkFormat3.InputContext.id

  `var sensorContextID`

    Field WacomInkFormat3.InputContext.sensorContextID

`class InputContextData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var environments`

    Field WacomInkFormat3.InputContextData.environments

  `var inkInputProviders`

    Field WacomInkFormat3.InputContextData.inkInputProviders

  `var inputContexts`

    Field WacomInkFormat3.InputContextData.inputContexts

  `var inputDevices`

    Field WacomInkFormat3.InputContextData.inputDevices

  `var sensorContexts`

    Field WacomInkFormat3.InputContextData.sensorContexts

`class InputData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var inputContextData`

    Field WacomInkFormat3.InputData.inputContextData

  `var sensorData`

    Field WacomInkFormat3.InputData.sensorData

`class InputDevice (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field WacomInkFormat3.InputDevice.id

  `var properties`

    Field WacomInkFormat3.InputDevice.properties

`class Matrix4 (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var m00`

    Field WacomInkFormat3.Matrix4.m00

  `var m01`

    Field WacomInkFormat3.Matrix4.m01

  `var m02`

    Field WacomInkFormat3.Matrix4.m02

  `var m03`

    Field WacomInkFormat3.Matrix4.m03

  `var m10`

    Field WacomInkFormat3.Matrix4.m10

  `var m11`

    Field WacomInkFormat3.Matrix4.m11

  `var m12`

    Field WacomInkFormat3.Matrix4.m12

  `var m13`

    Field WacomInkFormat3.Matrix4.m13

  `var m20`

    Field WacomInkFormat3.Matrix4.m20

  `var m21`

    Field WacomInkFormat3.Matrix4.m21

  `var m22`

    Field WacomInkFormat3.Matrix4.m22

  `var m23`

    Field WacomInkFormat3.Matrix4.m23

  `var m30`

    Field WacomInkFormat3.Matrix4.m30

  `var m31`

    Field WacomInkFormat3.Matrix4.m31

  `var m32`

    Field WacomInkFormat3.Matrix4.m32

  `var m33`

    Field WacomInkFormat3.Matrix4.m33

`class Node (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var chunkFromIndex`

    Field WacomInkFormat3.Node.chunkFromIndex

  `var chunkToIndex`

    Field WacomInkFormat3.Node.chunkToIndex

  `var depth`

    Field WacomInkFormat3.Node.depth

  `var groupBoundingBox`

    Field WacomInkFormat3.Node.groupBoundingBox

  `var id`

    Field WacomInkFormat3.Node.id

  `var index`

    Field WacomInkFormat3.Node.index

  `var type`

    Field WacomInkFormat3.Node.type

`class PathPointProperties (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var alpha`

    Field WacomInkFormat3.PathPointProperties.alpha

  `var blue`

    Field WacomInkFormat3.PathPointProperties.blue

  `var green`

    Field WacomInkFormat3.PathPointProperties.green

  `var offsetX`

    Field WacomInkFormat3.PathPointProperties.offsetX

  `var offsetY`

    Field WacomInkFormat3.PathPointProperties.offsetY

  `var offsetZ`

    Field WacomInkFormat3.PathPointProperties.offsetZ

  `var red`

    Field WacomInkFormat3.PathPointProperties.red

  `var rotation`

    Field WacomInkFormat3.PathPointProperties.rotation

  `var scaleX`

    Field WacomInkFormat3.PathPointProperties.scaleX

  `var scaleY`

    Field WacomInkFormat3.PathPointProperties.scaleY

  `var scaleZ`

    Field WacomInkFormat3.PathPointProperties.scaleZ

  `var size`

    Field WacomInkFormat3.PathPointProperties.size

`class Property (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var name`

    Field WacomInkFormat3.Property.name

  `var value`

    Field WacomInkFormat3.Property.value

`class Range (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var max`

    Field WacomInkFormat3.Range.max

  `var min`

    Field WacomInkFormat3.Range.min

  `var remapURI`

    Field WacomInkFormat3.Range.remapURI

`class RasterBrush (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var blendMode`

    Field WacomInkFormat3.RasterBrush.blendMode

  `var fillHeight`

    Field WacomInkFormat3.RasterBrush.fillHeight

  `var fillTexture`

    Field WacomInkFormat3.RasterBrush.fillTexture

  `var fillTextureURI`

    Field WacomInkFormat3.RasterBrush.fillTextureURI

  `var fillWidth`

    Field WacomInkFormat3.RasterBrush.fillWidth

  `var name`

    Field WacomInkFormat3.RasterBrush.name

  `var randomizeFill`

    Field WacomInkFormat3.RasterBrush.randomizeFill

  `var rotationMode`

    Field WacomInkFormat3.RasterBrush.rotationMode

  `var scattering`

    Field WacomInkFormat3.RasterBrush.scattering

  `var shapeTexture`

    Field WacomInkFormat3.RasterBrush.shapeTexture

  `var shapeTextureURI`

    Field WacomInkFormat3.RasterBrush.shapeTextureURI

  `var spacing`

    Field WacomInkFormat3.RasterBrush.spacing

`class Rectangle (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var height`

    Field WacomInkFormat3.Rectangle.height

  `var width`

    Field WacomInkFormat3.Rectangle.width

  `var x`

    Field WacomInkFormat3.Rectangle.x

  `var y`

    Field WacomInkFormat3.Rectangle.y

`class SemanticTriple (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var object`

    Field WacomInkFormat3.SemanticTriple.object

  `var predicate`

    Field WacomInkFormat3.SemanticTriple.predicate

  `var subject`

    Field WacomInkFormat3.SemanticTriple.subject

`class SensorChannel (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field WacomInkFormat3.SensorChannel.id

  `var max`

    Field WacomInkFormat3.SensorChannel.max

  `var metric`

    Field WacomInkFormat3.SensorChannel.metric

  `var min`

    Field WacomInkFormat3.SensorChannel.min

  `var precision`

    Field WacomInkFormat3.SensorChannel.precision

  `var resolution`

    Field WacomInkFormat3.SensorChannel.resolution

  `var type`

    Field WacomInkFormat3.SensorChannel.type

`class SensorChannelsContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var channels`

    Field WacomInkFormat3.SensorChannelsContext.channels

  `var id`

    Field WacomInkFormat3.SensorChannelsContext.id

  `var inkInputProviderID`

    Field WacomInkFormat3.SensorChannelsContext.inkInputProviderID

  `var inputDeviceID`

    Field WacomInkFormat3.SensorChannelsContext.inputDeviceID

  `var latency`

    Field WacomInkFormat3.SensorChannelsContext.latency

  `var samplingRateHint`

    Field WacomInkFormat3.SensorChannelsContext.samplingRateHint

`class SensorContext (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var id`

    Field WacomInkFormat3.SensorContext.id

  `var sensorChannelsContext`

    Field WacomInkFormat3.SensorContext.sensorChannelsContext

`class SensorData (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var dataChannels`

    Field WacomInkFormat3.SensorData.dataChannels

  `var id`

    Field WacomInkFormat3.SensorData.id

  `var inputContextID`

    Field WacomInkFormat3.SensorData.inputContextID

  `var state`

    Field WacomInkFormat3.SensorData.state

  `var timestamp`

    Field WacomInkFormat3.SensorData.timestamp

`class Stroke (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var alpha`

    Field WacomInkFormat3.Stroke.alpha

  `var blue`

    Field WacomInkFormat3.Stroke.blue

  `var endParameter`

    Field WacomInkFormat3.Stroke.endParameter

  `var green`

    Field WacomInkFormat3.Stroke.green

  `var id`

    Field WacomInkFormat3.Stroke.id

  `var offsetX`

    Field WacomInkFormat3.Stroke.offsetX

  `var offsetY`

    Field WacomInkFormat3.Stroke.offsetY

  `var offsetZ`

    Field WacomInkFormat3.Stroke.offsetZ

  `var red`

    Field WacomInkFormat3.Stroke.red

  `var rotation`

    Field WacomInkFormat3.Stroke.rotation

  `var scaleX`

    Field WacomInkFormat3.Stroke.scaleX

  `var scaleY`

    Field WacomInkFormat3.Stroke.scaleY

  `var scaleZ`

    Field WacomInkFormat3.Stroke.scaleZ

  `var sensorDataID`

    Field WacomInkFormat3.Stroke.sensorDataID

  `var sensorDataMapping`

    Field WacomInkFormat3.Stroke.sensorDataMapping

  `var sensorDataOffset`

    Field WacomInkFormat3.Stroke.sensorDataOffset

  `var size`

    Field WacomInkFormat3.Stroke.size

  `var splineX`

    Field WacomInkFormat3.Stroke.splineX

  `var splineY`

    Field WacomInkFormat3.Stroke.splineY

  `var splineZ`

    Field WacomInkFormat3.Stroke.splineZ

  `var startParameter`

    Field WacomInkFormat3.Stroke.startParameter

  `var style`

    Field WacomInkFormat3.Stroke.style

`class Style (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var brushURI`

    Field WacomInkFormat3.Style.brushURI

  `var particlesRandomSeed`

    Field WacomInkFormat3.Style.particlesRandomSeed

  `var properties`

    Field WacomInkFormat3.Style.properties

  `var renderModeURI`

    Field WacomInkFormat3.Style.renderModeURI

`class TripleStore (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var statements`

    Field WacomInkFormat3.TripleStore.statements

`class Uint32 (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var value`

    Field WacomInkFormat3.Uint32.value

`class VectorBrush (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var name`

    Field WacomInkFormat3.VectorBrush.name

  `var prototype`

    Field WacomInkFormat3.VectorBrush.prototype

  `var spacing`

    Field WacomInkFormat3.VectorBrush.spacing

`class View (*args, **kwargs)`

  A ProtocolMessage

  ### Ancestors

  - google.protobuf.pyext._message.CMessage
  - google.protobuf.message.Message

  ### Class variables

  `var DESCRIPTOR`

  ### Instance variables

  `var name`

    Field WacomInkFormat3.View.name

  `var tree`

    Field WacomInkFormat3.View.tree